@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2021 Statnet Commons
+#  Copyright 2008-2022 Statnet Commons
 ################################################################################
 #' @import statnet.common network ergm
 #' @useDynLib ergm.count
@@ -21,14 +21,7 @@
 }
 
 .RegisterProposals <- function(){
-  ergm_proposal_table("c", "Poisson", "",  0, "random", "Poisson")
-  ergm_proposal_table("c", "Poisson", "&sparse",  1, "TNT", "PoissonTNT")
+  ergm_proposal_table("c", c("Poisson","Binomial","Geometric","DiscUnif"), "|.dyads",  0, "random", "Disc")
+  ergm_proposal_table("c", c("Poisson","Binomial","Geometric","DiscUnif"), "&sparse|.dyads",  1, "TNT", "DiscTNT")
   ergm_proposal_table("c", "Poisson", "&sparse",  0, "0inflated", "ZIPoisson")
-  ergm_proposal_table("c", "Poisson", "observed",  0, "random", "PoissonNonObserved")
-
-  ergm_proposal_table("c", "Geometric", "",  0, "random", "Geometric")
-  ergm_proposal_table("c", "Geometric", "observed",  0, "random", "GeometricNonObserved")
-
-  ergm_proposal_table("c", "Binomial", "",  0, "random", "Binomial")
-  ergm_proposal_table("c", "Binomial", "observed",  0, "random", "BinomialNonObserved")
 }
